@@ -3,7 +3,10 @@ import sys
 import logging
 import shapely
 from shapely.geometry import MultiPoint
-import numpy
+import trimesh
+from typing import Union, Tuple, List
+import rtree  # Needed by trimesh
+import numpy as np
 try:
     import geopandas
     USE_GP = True
@@ -11,7 +14,7 @@ except ImportError:
     USE_GP = False
 
 
-def _testalpha(points, alpha):
+def _testalpha(points: Union[List[Tuple[float]], np.ndarray], alpha: float):
     """
     Evaluates an alpha parameter.
 
@@ -20,8 +23,8 @@ def _testalpha(points, alpha):
     intersects all the input points.
 
     Args:
-        points (``shapely.geometry.Multipoint``): data points
-        alpha (float): alpha value
+        points: data points
+        alpha: alpha value
 
     Returns:
         bool: True if the resulting alpha shape is a single polygon that
@@ -32,14 +35,19 @@ def _testalpha(points, alpha):
     except ImportError:
         from .alphashape import alphashape
     polygon = alphashape(points, alpha)
-    if isinstance(polygon, shapely.geometry.polygon.Polygon) and all(
-            [polygon.intersects(point) for point in points]):
-        return True
+    if isinstance(polygon, shapely.geometry.polygon.Polygon):
+        if not isinstance(points, MultiPoint):
+            points = MultiPoint(list(points))
+        return all([polygon.intersects(point) for point in points])
+    elif isinstance(polygon, trimesh.base.Trimesh):
+        return len(polygon.faces) > 0 and all(
+            trimesh.proximity.signed_distance(polygon, list(points)) >= 0)
     else:
         return False
 
 
-def optimizealpha(points, max_iterations: int = 10000, lower: float = 0.,
+def optimizealpha(points: Union[List[Tuple[float]], np.ndarray],
+                  max_iterations: int = 10000, lower: float = 0.,
                   upper: float = sys.float_info.max, silent: bool = False):
     """
     Solve for the alpha parameter.
@@ -53,12 +61,12 @@ def optimizealpha(points, max_iterations: int = 10000, lower: float = 0.,
 
     Args:
 
-        points (list): an iterable container of points
+        points: an iterable container of points
         max_iterations (int): maximum number of iterations while finding the
             solution
-        lower (float): lower limit for optimization
-        upper (float): upper limit for optimization
-        silent (bool): silence warnings
+        lower: lower limit for optimization
+        upper: upper limit for optimization
+        silent: silence warnings
 
     Returns:
 
@@ -68,8 +76,6 @@ def optimizealpha(points, max_iterations: int = 10000, lower: float = 0.,
     # Convert to a shapely multipoint object if not one already
     if USE_GP and isinstance(points, geopandas.GeoDataFrame):
         points = points['geometry']
-    if not isinstance(points, MultiPoint):
-        points = MultiPoint(list(points))
 
     # Set the bounds
     assert lower >= 0, "The lower bounds must be at least 0"
@@ -86,7 +92,7 @@ def optimizealpha(points, max_iterations: int = 10000, lower: float = 0.,
 
     # Begin the bisection loop
     counter = 0
-    while (upper - lower) > numpy.finfo(float).eps * 2:
+    while (upper - lower) > np.finfo(float).eps * 2:
         # Bisect the current bounds
         test_alpha = (upper + lower) * .5
 
